@@ -1,5 +1,5 @@
-man = []
-other = []
+a = []
+b = []
 from frula_nester import print_lol
 try:
         data = open("sketch2.txt") #type your .txt file
@@ -8,10 +8,10 @@ try:
                         (role,line_spoken) = each_line.split(":", 1)
                         line_spoken = line_spoken.strip()
                         if role == "A": #change role in your charachter, such as "Susane" 
-                                man.append(line_spoken)
+                                a.append(line_spoken)
 
                         elif role == "B":
-                                other.append(line_spoken)
+                                b.append(line_spoken)
                 except ValueError:
                         pass
         data.close()
